<?php
/*
Plugin Name: Multi-X Bar - Widget Area Pack
Plugin URI: http://www.icprojects.net/multi-x-bar-widget-areas.html
Description: This plugin adds Widget Areas to Multi-X Bar. Requires Multi-X Bar ver 2.30 or higher.
Author: Ivan Churakov
Author URI: http://www.icprojects.net/about
Version: 1.15
*/
add_action('plugins_loaded', 'multixwidgetareas_init');

function multixwidgetareas_init() {
	if (class_exists('multix_class') && class_exists('multix_module')) {
		class multix_widget_area_general_options extends multix_module {
			function __construct() {
				if (function_exists('load_plugin_textdomain')) {
					load_plugin_textdomain('multix', false, dirname(plugin_basename(__FILE__)).'/languages/');
				}
				$this->module = array("id" => "widgets_area_general", "title" => __('Widget Area General Settings', 'multix'), "settings" => true);
				$this->options = array (
					"number" => 0
				);
				$this->get_options();
				if (is_admin()) {
					add_action('multix_echo_options_general', array(&$this, 'admin_settings'));
					add_action('multix_save_options', array(&$this, 'save_options'));
				}
			}

			function admin_settings() {
				global $wpdb;
				print ('
							<table class="multix_useroptions">
								<tr>
									<th>'.__('Number of Widget Areas', 'multix').':</th>
									<td>
										<select id="'.$this->field_name('number').'" name="'.$this->field_name('number').'" style="width: 60px;">');
				for ($i=0; $i<=10; $i++) {
					echo '
											<option value="'.$i.'"'.($i == $this->options['number'] ? ' selected="selected"' : '').'>'.$i.'</option>';
				}
				print ('
										</select>
										<br /><em>'.__('Select number of additional widget areas.', 'multix').'</em>
									</td>
								</tr>
							</table>');
			}
				
			function save_options($active_modules = array()) {
				global $wpdb;
				$this->populate_options();
				$this->update_options();
			}
		}
		$multix_widget_area_general_options = new multix_widget_area_general_options();
	
		class multix_widget_area extends multix_module {
			var $number;
			function __construct($_number) {
				global $multix;
				if (function_exists('load_plugin_textdomain')) {
					load_plugin_textdomain('multix', false, dirname(plugin_basename(__FILE__)).'/languages/');
				}
				$this->number = $_number;
				$this->module = array("id" => "widgets-".$_number, "title" => __('Widget Area', 'multix').' #'.$_number, "settings" => true);
				
				$this->options = array (
					"label" => "Widget Area #".$_number,
					"width" => 250,
					"icon" => "fas fa-cog"
				);

				$this->get_options();
				
				add_action('widgets_init', array(&$this, 'admin_widgets_init'), 99);
				add_filter('multix_check_options', array(&$this, 'check_options'), 10, 2);
				
				if (is_admin()) {
					add_action('multix_echo_options_box', array(&$this, 'admin_settings'));
					add_action('multix_save_options', array(&$this, 'save_options'));
				} else {
					add_action('multix_echo_module', array(&$this, 'echo_module'));
					add_action('multix_front_header_style', array(&$this, 'front_header_style'), 10);
					add_action('multix_front_footer', array(&$this, 'front_footer'), 10, 2);
				}
				parent::__construct();
			}

			function check_options($_errors, $active_modules) {
				$errors = array();
				if (in_array($this->module['id'], $active_modules)) {
					if (strlen($this->options['label']) < 1) $errors[] = __('Widgets Module label must contain at least 1 characters', 'multix');
					if (!is_numeric($this->options['width']) || intval($this->options['width']) < 100 || intval($this->options['width']) > 800) $errors[] = __('Widgets Module width must be between 100 and 800 pixels', 'multix');
				}
				return array_merge($_errors, $errors);
			}

			function admin_widgets_init() {
				register_sidebar( array(
					'name' => __('Multi-X Bar Widget Area', 'multix' ).' #'.$this->number,
					'id' => 'multix-widgets-'.$this->number,
					'description' => __('Multi-X Bar Widget Area', 'multix' ).' #'.$this->number,
					'before_widget' => '<div id="%1$s" class="multix_widget %2$s">',
					'after_widget' => "</div>",
					'before_title' => '<h2 class="multix_widget_title">',
					'after_title' => '</h2>',
				));
			}

			function admin_settings() {
				global $wpdb, $multix;
				$reflector = new ReflectionClass('multix_class');
				$multix_path = $reflector->getFileName();
				if ($multix_path !== false) $multix_images_url = plugins_url('/images/', $multix_path);
				else $multix_images_url = WP_PLUGIN_URL.'/multix/images/';
				echo '
					<div class="postbox multix-invisible" id="multix-settings-'.$this->module['id'].'">
						<h3 class="hndle" style="cursor: default;"><span>'.__('Widget Area', 'multix').' #'.$this->number.' '.__('Settings', 'multix').'</span></h3>
						<div class="inside">
							<table class="multix_useroptions">
								<tr>
									<th>'.__('Area label', 'multix').':</th>
									<td><input type="text" id="'.$this->field_name('label').'" name="'.$this->field_name('label').'" value="'.htmlspecialchars($this->options['label'], ENT_QUOTES).'" class="widefat"><br /><em>'.__('Enter the label of Widget Area button.', 'multix').'</em></td>
								</tr>';
				if ($multix->options['fa_enable'] == 'on') {
					echo '
								<tr>
									<th>'.__('Link icon', 'multix').':</th>
									<td>
										<span id="'.$this->field_name('icon_image').'" class="multix-icon multix-icon-active" title="'.__('Icons', 'multix').'" onclick="jQuery(\'#'.$this->field_name('icon_set').'\').slideToggle(300);"><i class="'.$this->options['icon'].'"></i></span><br />
										<div id="'.$this->field_name('icon_set').'" class="multix-icon-set">';
					if ($multix->options['fa_solid_enable'] == 'on') {
						foreach ($multix->fa_solid as $value) {
							echo '<span class="multix-icon'.($this->options['icon'] == 'fas fa-'.$value ? ' multix-icon-active' : '').'" title="'.$value.'" onclick="multix_seticon(this, \''.$this->field_name('icon').'\');"><i class="fas fa-'.$value.'"></i></span>';
						}
					}
					if ($multix->options['fa_regular_enable'] == 'on') {
						foreach ($multix->fa_regular as $value) {
							echo '<span class="multix-icon'.($this->options['icon'] == 'far fa-'.$value ? ' multix-icon-active' : '').'" title="'.$value.'" onclick="multix_seticon(this, \''.$this->field_name('icon').'\');"><i class="far fa-'.$value.'"></i></span>';
						}
					}
					if ($multix->options['fa_brands_enable'] == 'on') {
						foreach ($multix->fa_brands as $value) {
							echo '<span class="multix-icon'.($this->options['icon'] == 'fab fa-'.$value ? ' multix-icon-active' : '').'" title="'.$value.'" onclick="multix_seticon(this, \''.$this->field_name('icon').'\');"><i class="fab fa-'.$value.'"></i></span>';
						}
					}
					echo '
										</div>
										<input type="hidden" name="'.$this->field_name('icon').'" id="'.$this->field_name('icon').'" value="'.$this->options['icon'].'">
										<em>'.__('Select desired module icon.', 'multix').'</em>
									</td>
								</tr>';
				}
				echo '
								<tr>
									<th>'.__('Area width', 'multix').':</th>
									<td>
										<input type="text" id="'.$this->field_name('width').'" name="'.$this->field_name('width').'" value="'.htmlspecialchars($this->options['width'], ENT_QUOTES).'" style="width: 80px; text-align: right;">
										<br /><em>'.__('Please set the width of Widget Area.', 'multix').'</em>
									</td>
								</tr>
							</table>
							<div class="alignright">
							<input type="submit" class="multix_button button-primary" name="submit" value="'.__('Update Settings', 'multix').'">
							</div>
						</div>
					</div>';
			}
				
			function save_options($active_modules = array()) {
				global $wpdb;
				if (in_array($this->module['id'], $active_modules)) {
					$this->populate_options();
					$this->update_options();
				}
			}
				
			function echo_module($_moduleid) {
				echo '
			'.($_moduleid == $this->module['id'] ? '<a id="multix_widgets_area_'.$this->number.'_link" class="multix_boxedlink multix_right" href="#multix_widgets_container_'.$this->number.'" title="'.esc_attr($this->options['label']).'"><i class="fa '.$this->options['icon'].'"></i><span>'.esc_attr($this->options['label']).'</span></a>' : '');
			}

			function front_header_style($active_modules) {
				global $multix;
				if (in_array($this->module['id'], $active_modules)) {
					echo '';
				}
			}

			function front_footer($active_modules, $class) {
				if (in_array($this->module['id'], $active_modules)) {
					echo '
		<div id="multix_widgets_container_'.$this->number.'" class="multix_box_container '.$class.'" style="width: '.$this->options['width'].'px;">
			<div style="overflow: hidden; height: 100%; margin: 10px 10px 10px 10px;">';
					if (!dynamic_sidebar('multix-widgets-'.$this->number)) {
						echo '
				'.__('Please go to widget settings page and pull desired widgets to Multi-X Bar Widget Area', 'multix').' #'.$this->number.'.';
					}
					echo '
			</div>
			<span class="multix_box_close">×</span>
		</div>';
				}
			}
		}
		if (!defined('MULTIX_VERSION') || MULTIX_VERSION < 2.3) {
			add_action('admin_notices', 'multixwidgetarea_oldmultix');
		} else {
			$multix_widget_areas = array();
			for($i=1; $i<=$multix_widget_area_general_options->options['number']; $i++) {
				$multix_widget_areas[] = new multix_widget_area($i);
			}
		}
	} else {
		add_action('admin_notices', 'multixwidgetarea_nomultix');
	}
}

function multixwidgetarea_nomultix() {
	echo '
		<div class="updated"><p>'.__('Please activate <strong>Multi-X Bar</strong> plugin to use <strong>Multi-X Bar - Widget Area Pack</strong>. Get your copy of Multi-X Bar <strong><a href="http://codecanyon.net/item/multix-bar/3741886?ref=ichurakov">here</a></strong>.', 'multix').'</p></div>';
}
function multixwidgetarea_oldmultix() {
	echo '
		<div class="updated"><p>'.__('<strong>Multi-X Bar - Widget Area Pack</strong> requires <strong>Multi-X Bar</strong> ver <strong>2.30</strong> or higher to be installed. Get latest copy of Multi-X Bar <strong><a href="http://codecanyon.net/item/multix-bar/3741886?ref=ichurakov">here</a></strong>.', 'multix').'</p></div>';
}

?>